@@ -324,9 +324,6 @@ build_object (GoaProvider         *provider,
   GoaAccount *account;
   GoaMail *mail;
   gchar *uri_caldav;
-  GoaChat *chat;
-  GoaPhotos *photos;
-  GoaPrinters *printers;
   gchar *uri_drive;
   gboolean ret;
   gboolean mail_enabled;
@@ -341,9 +338,6 @@ build_object (GoaProvider         *provider,
 
   account = NULL;
   mail = NULL;
-  chat = NULL;
-  photos = NULL;
-  printers = NULL;
   ret = FALSE;
 
   /* Chain up */
@@ -402,48 +396,17 @@ build_object (GoaProvider         *provider,
                                        contacts_enabled,
                                        FALSE);
 
-#ifdef GOA_TELEPATHY_ENABLED
   /* Chat */
-  chat = goa_object_get_chat (GOA_OBJECT (object));
   chat_enabled = g_key_file_get_boolean (key_file, group, "ChatEnabled", NULL);
-  if (chat_enabled)
-    {
-      if (chat == NULL)
-        {
-          chat = goa_chat_skeleton_new ();
-          goa_object_skeleton_set_chat (object, chat);
-        }
-    }
-  else
-    {
-      if (chat != NULL)
-        goa_object_skeleton_set_chat (object, NULL);
-    }
-#else
-  goa_object_skeleton_set_chat (object, NULL);
-#endif
+  goa_object_skeleton_attach_chat (object, chat_enabled);
 
   /* Documents */
   documents_enabled = g_key_file_get_boolean (key_file, group, "DocumentsEnabled", NULL);
   goa_object_skeleton_attach_documents (object, documents_enabled);
 
   /* Photos */
-  photos = goa_object_get_photos (GOA_OBJECT (object));
   photos_enabled = g_key_file_get_boolean (key_file, group, "PhotosEnabled", NULL);
-
-  if (photos_enabled)
-    {
-      if (photos == NULL)
-        {
-          photos = goa_photos_skeleton_new ();
-          goa_object_skeleton_set_photos (object, photos);
-        }
-    }
-  else
-    {
-      if (photos != NULL)
-        goa_object_skeleton_set_photos (object, NULL);
-    }
+  goa_object_skeleton_attach_photos (object, photos_enabled);
 
   /* Files */
   files_enabled = g_key_file_get_boolean (key_file, group, "FilesEnabled", NULL);
@@ -452,22 +415,8 @@ build_object (GoaProvider         *provider,
   g_free (uri_drive);
 
   /* Printers */
-  printers = goa_object_get_printers (GOA_OBJECT (object));
   printers_enabled = g_key_file_get_boolean (key_file, group, "PrintersEnabled", NULL);
-
-  if (printers_enabled)
-    {
-      if (printers == NULL)
-        {
-          printers = goa_printers_skeleton_new ();
-          goa_object_skeleton_set_printers (object, printers);
-        }
-    }
-  else
-    {
-      if (printers != NULL)
-        goa_object_skeleton_set_printers (object, NULL);
-    }
+  goa_object_skeleton_attach_printers (object, printers_enabled);
 
   if (just_added)
     {
@@ -517,9 +466,6 @@ build_object (GoaProvider         *provider,
   ret = TRUE;
 
  out:
-  g_clear_object (&printers);
-  g_clear_object (&photos);
-  g_clear_object (&chat);
   g_clear_object (&mail);
   g_clear_object (&account);
   return ret;
