@@ -24,6 +24,7 @@
 #include <sys/timerfd.h>
 #endif
 
+#include <errno.h>
 #include <unistd.h>
 #include <string.h>
 
@@ -324,7 +325,7 @@ schedule_wakeups_with_timerfd (GoaAlarm *self)
 
   if (fd < 0)
     {
-      g_debug ("GoaAlarm: could not create timer fd: %m");
+      g_debug ("GoaAlarm: could not create timer fd: %s", strerror (errno));
       return FALSE;
     }
 
@@ -337,7 +338,7 @@ schedule_wakeups_with_timerfd (GoaAlarm *self)
 
   if (result < 0)
     {
-      g_debug ("GoaAlarm: could not set timer: %m");
+      g_debug ("GoaAlarm: could not set timer: %s", strerror (errno));
       return FALSE;
     }
 
